==> react-polymorph-0.7.0.tgz: package/__tests__/FormField.test.js <==
import React from 'react';
import renderer from 'react-test-renderer';

import { FormField } from '../source/components';
import { FormFieldSkin } from '../source/skins/simple';
import { CONTEXT } from './helpers/context';

const renderFormField = () => <div className="render-prop" />;

test('FormField renders correctly', () => {
  const component = renderer.create(
    <FormField
      context={CONTEXT}
      skin={FormFieldSkin}
      render={renderFormField}
    />
  );

  const tree = component.toJSON();
  expect(tree).toMatchSnapshot();
});

test('FormField renders with label', () => {
  const component = renderer.create(
    <FormField
      label="Add a Label"
      context={CONTEXT}
      skin={FormFieldSkin}
      render={renderFormField}
    />
  );

  const tree = component.toJSON();
  expect(tree).toMatchSnapshot();
});

test('FormField renders with an error', () => {
  const component = renderer.create(
    <FormField
      error="Add an Error"
      context={CONTEXT}
      skin={FormFieldSkin}
      render={renderFormField}
    />
  );

  const tree = component.toJSON();
  expect(tree).toMatchSnapshot();
});

test('FormField is disabled', () => {
  const component = renderer.create(
    <FormField
      disabled
      context={CONTEXT}
      skin={FormFieldSkin}
      render={({ disabled }) => <span>{disabled.toString()}</span>}
    />
  );

  const tree = component.toJSON();
  expect(tree).toMatchSnapshot();
});

test('FormField renders an input element', () => {
  const component = renderer.create(
    <FormField
      context={CONTEXT}
      skin={FormFieldSkin}
      render={() => <input className="render-prop" />}
    />
  );

  const tree = component.toJSON();
  expect(tree).toMatchSnapshot();
});

==> react-polymorph-0.7.2.tgz: package/__tests__/FormField.test.js <==
import React from 'react';

import { FormField } from '../source/components/FormField';
import { FormFieldSkin } from '../source/skins/simple/FormFieldSkin';
import { renderInSimpleTheme } from './helpers/theming';

const renderFormField = () => <div className="render-prop" />;

test('FormField renders correctly', () => {
  const component = renderInSimpleTheme(
    <FormField
      skin={FormFieldSkin}
      render={renderFormField}
    />
  );

  const tree = component.toJSON();
  expect(tree).toMatchSnapshot();
});

test('FormField renders with label', () => {
  const component = renderInSimpleTheme(
    <FormField
      label="Add a Label"
      skin={FormFieldSkin}
      render={renderFormField}
    />
  );

  const tree = component.toJSON();
  expect(tree).toMatchSnapshot();
});

test('FormField renders with an error', () => {
  const component = renderInSimpleTheme(
    <FormField
      error="Add an Error"
      skin={FormFieldSkin}
      render={renderFormField}
    />
  );

  const tree = component.toJSON();
  expect(tree).toMatchSnapshot();
});

test('FormField is disabled', () => {
  const component = renderInSimpleTheme(
    <FormField
      disabled
      skin={FormFieldSkin}
      render={({ disabled }) => <span>{disabled.toString()}</span>}
    />
  );

  const tree = component.toJSON();
  expect(tree).toMatchSnapshot();
});

test('FormField renders an input element', () => {
  const component = renderInSimpleTheme(
    <FormField
      skin={FormFieldSkin}
      render={() => <input className="render-prop" />}
    />
  );

  const tree = component.toJSON();
  expect(tree).toMatchSnapshot();
});
